@@ -1,20 +1,13 @@
-# Back In Time
-# Copyright (C) 2008-2022 Oprea Dan, Bart de Koning, Richard Bailey, Germar Reitze
+# SPDX-FileCopyrightText: © 2008-2022 Oprea Dan
+# SPDX-FileCopyrightText: © 2008-2022 Bart de Koning
+# SPDX-FileCopyrightText: © 2008-2022 Richard Bailey
+# SPDX-FileCopyrightText: © 2008-2022 Germar Reitze
 #
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version.
+# SPDX-License-Identifier: GPL-2.0-or-later
 #
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License along
-# with this program; if not, write to the Free Software Foundation,Inc.,
-# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
-
+# This file is part of the program "Back In Time" which is released under GNU
+# General Public License v2 (GPLv2). See LICENSES directory or go to
+# <https://spdx.org/licenses/GPL-2.0-or-later.html>.
 import os
 import sys
 import unittest
@@ -28,6 +21,7 @@ import configfile
 import snapshots
 from snapshotlog import LogFilter, SnapshotLog
 
+
 class TestSID(generic.SnapshotsTestCase):
     def test_new_object_with_valid_date(self):
         sid1 = snapshots.SID('20151219-010324-123', self.cfg)
@@ -308,7 +302,7 @@ class TestSID(generic.SnapshotsTestCase):
         os.makedirs(os.path.join(self.snapshotPath, '20151219-010324-123'))
         infoFile = sid.path(sid.FILEINFO)
         # remove all permissions from file
-        with open(infoFile, 'wt') as f:
+        with open(infoFile, 'wt'):
             pass
 
         with generic.mockPermissions(infoFile):
@@ -321,7 +315,7 @@ class TestSID(generic.SnapshotsTestCase):
         os.makedirs(os.path.join(self.snapshotPath, '20151219-010324-123'))
         infoFile = sid.path(sid.FILEINFO)
         # remove all permissions from file
-        with open(infoFile, 'wt') as f:
+        with open(infoFile, 'wt'):
             pass
 
         with generic.mockPermissions(infoFile):
@@ -392,6 +386,7 @@ class TestSID(generic.SnapshotsTestCase):
             msg = 'writing to {} raised PermissionError unexpectedly!'
             self.fail(msg.format(testFile))
 
+
 class TestNewSnapshot(generic.SnapshotsTestCase):
     def test_create_new(self):
         new = snapshots.NewSnapshot(self.cfg)
@@ -437,6 +432,7 @@ class TestNewSnapshot(generic.SnapshotsTestCase):
         log.flush()
         self.assertTrue(new.hasChanges)
 
+
 class TestRootSnapshot(generic.SnapshotsTestCase):
     #TODO: add test with 'sid.path(use_mode=['ssh_encfs'])'
     def test_create(self):
@@ -450,6 +446,7 @@ class TestRootSnapshot(generic.SnapshotsTestCase):
         self.assertEqual(sid.path(), '/')
         self.assertEqual(sid.path('foo', 'bar'), '/foo/bar')
 
+
 class TestIterSnapshots(generic.SnapshotsTestCase):
     def setUp(self):
         super(TestIterSnapshots, self).setUp()
@@ -542,9 +539,10 @@ class TestIterSnapshots(generic.SnapshotsTestCase):
         self.assertEqual(snapshots.lastSnapshot(self.cfg),
                          '20151219-040324-123')
 
+
 class TestIterSnapshotsNonexistingSnapshotPath(generic.TestCaseSnapshotPath):
     def test_iterSnapshots(self):
-        for item in snapshots.iterSnapshots(self.cfg):
+        for _ in snapshots.iterSnapshots(self.cfg):
             self.fail('got unexpected snapshot')
 
     def test_listSnapshots(self):
@@ -553,5 +551,6 @@ class TestIterSnapshotsNonexistingSnapshotPath(generic.TestCaseSnapshotPath):
     def test_lastSnapshots(self):
         self.assertIsNone(snapshots.lastSnapshot(self.cfg))
 
+
 if __name__ == '__main__':
     unittest.main()
