@@ -11,13 +11,27 @@ VER=`cat VERSION`
 CURRENT=$(pwd)
 NEW="backintime-$VER"
 
+# clean up
+rm ./common/man/C/*.gz
+
 cd ..
-if [[ -n "$(which git)" ]] && [[ -x "$(which git)" ]]; then
-    git clone ${CURRENT} ${NEW}
-else
-    cp -aR ${CURRENT} ${NEW}
-fi
+
+# if [[ -n "$(which git)" ]] && [[ -x "$(which git)" ]]; then
+#     git clone ${CURRENT} ${NEW}
+# else
+#     cp -aR ${CURRENT} ${NEW}
+# fi
+
+cp --exclude=.git -aR ${CURRENT} ${NEW}
+
+rm backintime-$VER.tar.gz
+
 tar cfz backintime-$VER.tar.gz \
+    --exclude="*/__pycache__" \
+    --exclude="*/.pytest_cache" \
+    --exclude="*/.ruff_cache" \
+    --exclude="*/po/*.mo" \
+    --exclude-vcs \
     ${NEW}/AUTHORS \
     ${NEW}/CHANGES \
     ${NEW}/LICENSE \
@@ -30,7 +44,13 @@ tar cfz backintime-$VER.tar.gz \
     ${NEW}/updateversion.sh \
     ${NEW}/common \
     ${NEW}/qt \
+    ${NEW}/LICENSES \
     ${NEW}/doc
 
-rm -rf backintime-$VER
+tar -tzf backintime-$VER.tar.gz
+echo ""
+echo "RESULT:"
+realpath backintime-$VER.tar.gz
+
+# rm -rf backintime-$VER
 
