@@ -3,6 +3,7 @@
 # SPDX-FileCopyrightText: © 2008-2022 Richard Bailey
 # SPDX-FileCopyrightText: © 2008-2022 Germar Reitze
 # SPDX-FileCopyrightText: © 2024 Christian Buhtz <c.buhtz@posteo.jp>
+# SPDX-FileCopyrightText: © 2025 Samuel Moore
 #
 # SPDX-License-Identifier: GPL-2.0-or-later
 #
@@ -17,23 +18,23 @@ if not os.getenv('DISPLAY', ''):
 
 import pathlib
 import re
+import json
 import subprocess
 import shutil
+import textwrap
 import signal
 from contextlib import contextmanager
 from tempfile import TemporaryDirectory
-
 # We need to import common/tools.py
 import qttools_path
 qttools_path.registerBackintimePath('common')
-
 # Workaround until the codebase is rectified/equalized.
 import tools
 tools.initiate_translation(None)
-
 import qttools
-
 import backintime
+import bitbase
+import config
 import tools
 import logger
 import snapshots
@@ -42,8 +43,9 @@ import mount
 import progress
 import encfsmsgbox
 from exceptions import MountException
-
+from statedata import StateData
 from PyQt6.QtGui import (QAction,
+                         QActionGroup,
                          QShortcut,
                          QDesktopServices,
                          QPalette,
@@ -74,28 +76,29 @@ from PyQt6.QtWidgets import (QWidget,
                              QDialog,
                              QApplication,
                              )
-from PyQt6.QtCore import (Qt,
+from PyQt6.QtCore import (QDir,
+                          QEvent,
                           QObject,
                           QPoint,
                           pyqtSlot,
                           pyqtSignal,
+                          QSortFilterProxyModel,
+                          Qt,
                           QTimer,
                           QThread,
-                          QEvent,
-                          QSortFilterProxyModel,
-                          QDir,
                           QUrl)
-from manageprofiles import SettingsDialog
 import snapshotsdialog
 import logviewdialog
-from restoredialog import RestoreDialog
-from restoreconfigdialog import RestoreConfigDialog
 import languagedialog
 import messagebox
-from aboutdlg import AboutDlg
 import qttools
-from usermessagedialog import UserMessageDialog
 import version
+from manageprofiles import SettingsDialog
+from restoredialog import RestoreDialog
+from restoreconfigdialog import RestoreConfigDialog
+from usermessagedialog import UserMessageDialog
+from aboutdlg import AboutDlg
+from statedata import StateData
 
 
 class MainWindow(QMainWindow):
@@ -123,6 +126,8 @@ class MainWindow(QMainWindow):
         # window icon
         self.qapp.setWindowIcon(icon.BIT_LOGO)
 
+        state_data = StateData()
+
         # shortcuts without buttons
         self._create_shortcuts_without_actions()
 
@@ -224,13 +229,10 @@ class MainWindow(QMainWindow):
         self.filesViewDelegate = QStyledItemDelegate(self)
         self.filesView.setItemDelegate(self.filesViewDelegate)
 
-        sortColumn = self.config.intValue(
-            'qt.main_window.files_view.sort.column', 0)
-        sortOrder = self.config.boolValue(
-            'qt.main_window.files_view.sort.ascending', True)
-        sortOrder = Qt.SortOrder.AscendingOrder if sortOrder else Qt.SortOrder.DescendingOrder
+        sortColumn, sortOrder = state_data.files_view_sorting
 
-        self.filesView.header().setSortIndicator(sortColumn, sortOrder)
+        self.filesView.header().setSortIndicator(
+            sortColumn, Qt.SortOrder(sortOrder))
         self.filesViewModel.sort(
             self.filesView.header().sortIndicatorSection(),
             self.filesView.header().sortIndicatorOrder())
@@ -291,50 +293,37 @@ class MainWindow(QMainWindow):
 
         self.snapshotsList = []
         self.sid = snapshots.RootSnapshot(self.config)
-        self.path = self.config.profileStrValue(
-            'qt.last_path',
-            self.config.strValue('qt.last_path', '/')
-        )
+        self.path = self.config.profileStrValue('qt.last_path', '/')
         self.widget_current_path.setText(self.path)
         self.path_history = tools.PathHistory(self.path)
 
-        # restore size and position
-        x = self.config.intValue('qt.main_window.x', -1)
-        y = self.config.intValue('qt.main_window.y', -1)
-        if x >= 0 and y >= 0:
-            self.move(x, y)
+        # restore position and size
+        try:
+            self.move(*state_data.mainwindow_coords)
+            self.resize(*state_data.mainwindow_dims)
+        except KeyError:
+            pass
 
-        w = self.config.intValue('qt.main_window.width', 800)
-        h = self.config.intValue('qt.main_window.height', 500)
-        self.resize(w, h)
+        self.mainSplitter.setSizes(
+            state_data.mainwindow_main_splitter_widths)
+        self.secondSplitter.setSizes(
+            state_data.mainwindow_second_splitter_widths)
 
-        mainSplitterLeftWidth = self.config.intValue(
-            'qt.main_window.main_splitter_left_w', 150)
-        mainSplitterRightWidth = self.config.intValue(
-            'qt.main_window.main_splitter_right_w', 450)
-        sizes = [mainSplitterLeftWidth, mainSplitterRightWidth]
-        self.mainSplitter.setSizes(sizes)
+        # FilesView: Column width
+        try:
+            files_view_col_widths = state_data.files_view_col_widths
+        except KeyError:
+            pass
+        else:
+            for idx, width in enumerate(files_view_col_widths):
+                self.filesView.header().resizeSection(idx, width)
 
-        secondSplitterLeftWidth = self.config.intValue(
-            'qt.main_window.second_splitter_left_w', 150)
-        secondSplitterRightWidth = self.config.intValue(
-            'qt.main_window.second_splitter_right_w', 300)
-        sizes = [secondSplitterLeftWidth, secondSplitterRightWidth]
-        self.secondSplitter.setSizes(sizes)
-
-        filesViewColumnNameWidth = self.config.intValue(
-            'qt.main_window.files_view.name_width', -1)
-        filesViewColumnSizeWidth = self.config.intValue(
-            'qt.main_window.files_view.size_width', -1)
-        filesViewColumnDateWidth = self.config.intValue(
-            'qt.main_window.files_view.date_width', -1)
-
-        if (filesViewColumnNameWidth > 0
-                and filesViewColumnSizeWidth > 0
-                and filesViewColumnDateWidth > 0):
-            self.filesView.header().resizeSection(0, filesViewColumnNameWidth)
-            self.filesView.header().resizeSection(1, filesViewColumnSizeWidth)
-            self.filesView.header().resizeSection(2, filesViewColumnDateWidth)
+        # Release Candidate
+        if version.is_release_candidate():
+            last_vers = state_data.msg_release_candidate
+            if last_vers != version.__version__:
+                state_data.msg_release_candidate = version.__version__
+                self._open_release_candidate_dialog()
 
         # Force dialog to import old configuration
         if not config.isConfigured():
@@ -408,24 +397,24 @@ class MainWindow(QMainWindow):
 
         SetupCron(self).start()
 
-        # Finished countdown of manual GUI starts
-        if 0 == self.config.manual_starts_countdown():
+        # Countdown of manual GUI starts finished?
+        if 0 == state_data.manual_starts_countdown():
 
             # Do nothing if English is the current used language
             if self.config.language_used != 'en':
 
                 # Show the message only if the current used language is
-                # translated equal or less then 97%
-                self._open_approach_translator_dialog(cutoff=97)
+                # translated equal or less then {cutoff}%
+                self._open_approach_translator_dialog(cutoff=99)
 
         # BIT counts down how often the GUI was started. Until the end of that
         # countdown a dialog with a text about contributing to translating
         # BIT is presented to the users.
-        self.config.decrement_manual_starts_countdown()
-
-        # If the encfs-deprecation warning was never shown before
-        if self.config.boolValue('internal.msg_shown_encfs') == False:
+        state_data.decrement_manual_starts_countdown()
 
+        # If the encfs-deprecation warning in its latest stage was not shown
+        # yet.
+        if state_data.msg_encfs_global < bitbase.ENCFS_MSG_STAGE:
             # Are there profiles using EncFS?
             encfs_profiles = []
             for pid in self.config.profiles():
@@ -435,25 +424,19 @@ class MainWindow(QMainWindow):
 
             # EncFS deprecation warning (#1734, #1735)
             if encfs_profiles:
+                state_data.msg_encfs_global = bitbase.ENCFS_MSG_STAGE
                 dlg = encfsmsgbox.EncfsExistsWarning(self, encfs_profiles)
                 dlg.exec()
-                self.config.setBoolValue('internal.msg_shown_encfs', True)
-
-        # Release Candidate
-        if version.is_release_candidate():
-            last_vers = self.config.strValue('internal.msg_rc')
-            if last_vers != version.__version__:
-                self.config.setStrValue('internal.msg_rc', version.__version__)
-                self._open_release_candidate_dialog()
 
     @property
     def showHiddenFiles(self):
-        return self.config.boolValue('qt.show_hidden_files', False)
+        state_data = StateData()
+        return state_data.mainwindow_show_hidden
 
-    # TODO The qt.show_hidden_files key should be a constant instead of a duplicated string
     @showHiddenFiles.setter
     def showHiddenFiles(self, value):
-        self.config.setBoolValue('qt.show_hidden_files', value)
+        state_data = StateData()
+        state_data.mainwindow_show_hidden = value
 
     def _create_actions(self):
         """Create all action objects used by this main window.
@@ -542,25 +525,40 @@ class MainWindow(QMainWindow):
                 icon.EXIT, _('Exit'),
                 self.close, ['Ctrl+Q'],
                 None),
-            'act_help_help': (
-                icon.HELP, _('Help'),
-                self.btnHelpClicked, ['F1'],
-                None),
-            'act_help_configfile': (
-                icon.HELP, _('Profiles config file'),
-                self.btnHelpConfigClicked, None, None),
+            'act_help_user_manual': (
+                icon.HELP, _('User manual'),
+                self.btn_help_user_manual, ['F1'],
+                _('Open user manual in browser (local if '
+                  'available otherwise online)'),
+            ),
+            'act_help_man_backintime': (
+                icon.HELP, _('man page: Back In Time'),
+                self.btn_help_man_backintime, None,
+                _('Displays man page about Back In Time (backintime)')
+            ),
+            'act_help_man_config': (
+                icon.HELP, _('man page: Profiles config file'),
+                self.btn_help_man_config,
+                None,
+                _('Displays man page about profiles config file '
+                  '(backintime-config)')
+            ),
             'act_help_website': (
-                icon.WEBSITE, _('Website'),
-                self.btnWebsiteClicked, None, None),
+                icon.WEBSITE, _('Project website'),
+                self.btnWebsiteClicked,
+                None,
+                _('Open Back In Time website in browser')),
             'act_help_changelog': (
                 icon.CHANGELOG, _('Changelog'),
                 self.btnChangelogClicked, None, None),
             'act_help_faq': (
                 icon.FAQ, _('FAQ'),
-                self.btnFaqClicked, None, None),
+                self.btnFaqClicked, None,
+                _('Open Frequently Asked Questions (FAQ) in browser')),
             'act_help_question': (
                 icon.QUESTION, _('Ask a question'),
-                self.btnAskQuestionClicked, None, None),
+                self.btnAskQuestionClicked, None,
+                None),
             'act_help_bugreport': (
                 icon.BUG, _('Report a bug'),
                 self.btnReportBugClicked, None, None),
@@ -698,8 +696,9 @@ class MainWindow(QMainWindow):
                 self.act_restore_parent_to,
             ),
             _('&Help'): (
-                self.act_help_help,
-                self.act_help_configfile,
+                self.act_help_user_manual,
+                self.act_help_man_backintime,
+                self.act_help_man_config,
                 self.act_help_website,
                 self.act_help_changelog,
                 self.act_help_faq,
@@ -738,12 +737,66 @@ class MainWindow(QMainWindow):
         restore.insertSeparator(self.act_restore_parent)
         restore.setToolTipsVisible(True)
 
+    def _button_styles(self):
+        return (
+            (
+                _('Icons only'),
+                Qt.ToolButtonStyle.ToolButtonIconOnly),
+            (
+                _('Text only'),
+                Qt.ToolButtonStyle.ToolButtonTextOnly),
+            (
+                _('Text below icons'),
+                Qt.ToolButtonStyle.ToolButtonTextUnderIcon),
+            (
+                _('Text beside icon'),
+                Qt.ToolButtonStyle.ToolButtonTextBesideIcon),
+        )
+
+    def _set_toolbar_button_style(self, toolbar, style):
+        """Set toolbar button style and store the selected index."""
+        toolbar.setToolButtonStyle(style)
+        StateData().toolbar_button_style = style.value
+
+    def _context_menu_button_style(self,
+                                    point: QPoint,
+                                    toolbar: QToolBar) -> None:
+        """Open a context menu to modify styling of tooblar buttons
+        buttons.
+        """
+        menu = QMenu(self)
+        group = QActionGroup(self)
+
+
+        for text, style in self._button_styles():
+            action = QAction(text, self)
+            action.setCheckable(True)
+            action.setChecked(toolbar.toolButtonStyle() == style)
+            group.addAction(action)
+            action.triggered.connect(
+                lambda _, s=style:
+                self._set_toolbar_button_style(toolbar, s)
+                )
+
+        menu.addActions(group.actions())
+
+        menu.exec(toolbar.mapToGlobal(point))
+
     def _create_main_toolbar(self):
         """Create the main toolbar and connect it to actions."""
 
         toolbar = self.addToolBar('main')
         toolbar.setFloatable(False)
 
+        # Context menu to modify button styling for main toolbar
+        toolbar.setContextMenuPolicy(Qt.ContextMenuPolicy.CustomContextMenu)
+        toolbar.customContextMenuRequested.connect(
+            lambda point: self._context_menu_button_style(point, toolbar))
+
+        # Restore button styling for main toolbar
+        toolbar.setToolButtonStyle(
+            Qt.ToolButtonStyle(StateData().toolbar_button_style))
+
         # Drop-Down: Profiles
         self.comboProfiles = qttools.ProfileCombo(self)
         self.comboProfilesAction = toolbar.addWidget(self.comboProfiles)
@@ -779,6 +832,8 @@ class MainWindow(QMainWindow):
 
                 toolbar.widgetForAction(act).setToolTip(button_tip)
 
+            act.setText(textwrap.fill(act.text(), width=8, break_long_words=False))
+
         # toolbar sub menu: take snapshot
         submenu_take_snapshot = QMenu(self)
         submenu_take_snapshot.addAction(self.act_take_snapshot)
@@ -835,6 +890,9 @@ class MainWindow(QMainWindow):
         return toolbar
 
     def closeEvent(self, event):
+        state_data = StateData()
+        profile_state = state_data.profile(self.config.current_profile_id)
+
         if self.shutdown.askBeforeQuit():
             msg = _('If you close this window, Back In Time will not be able '
                     'to shut down your system when the snapshot is finished.')
@@ -844,46 +902,38 @@ class MainWindow(QMainWindow):
             if answer != QMessageBox.StandardButton.Yes:
                 return event.ignore()
 
-        self.config.setStrValue('qt.last_path', self.path)
-        self.config.setProfileStrValue('qt.last_path', self.path)
-
-        self.config.setProfileIntValue(
-            'qt.places.SortColumn',
-            self.places.header().sortIndicatorSection())
-        self.config.setProfileIntValue(
-            'qt.places.SortOrder',
-            self.places.header().sortIndicatorOrder())
-
-        self.config.setIntValue('qt.main_window.x', self.x())
-        self.config.setIntValue('qt.main_window.y', self.y())
-        self.config.setIntValue('qt.main_window.width', self.width())
-        self.config.setIntValue('qt.main_window.height', self.height())
-
-        sizes = self.mainSplitter.sizes()
-        self.config.setIntValue('qt.main_window.main_splitter_left_w', sizes[0])
-        self.config.setIntValue('qt.main_window.main_splitter_right_w', sizes[1])
-
-        sizes = self.secondSplitter.sizes()
-        self.config.setIntValue('qt.main_window.second_splitter_left_w', sizes[0])
-        self.config.setIntValue('qt.main_window.second_splitter_right_w', sizes[1])
-
-        self.config.setIntValue('qt.main_window.files_view.name_width', self.filesView.header().sectionSize(0))
-        self.config.setIntValue('qt.main_window.files_view.size_width', self.filesView.header().sectionSize(1))
-        self.config.setIntValue('qt.main_window.files_view.date_width', self.filesView.header().sectionSize(2))
-
-        self.config.setIntValue('qt.main_window.files_view.sort.column', self.filesView.header().sortIndicatorSection())
-        self.config.setBoolValue('qt.main_window.files_view.sort.ascending', self.filesView.header().sortIndicatorOrder() == Qt.SortOrder.AscendingOrder)
+        profile_state.last_path = pathlib.Path(self.path)
+        profile_state.places_sorting = (
+            self.places.header().sortIndicatorSection(),
+            self.places.header().sortIndicatorOrder().value,
+        )
+        state_data.mainwindow_coords = (self.x(), self.y())
+        state_data.mainwindow_dims = (self.width(), self.height())
+        state_data.mainwindow_main_splitter_widths = self.mainSplitter.sizes()
+        state_data.mainwindow_second_splitter_widths \
+            = self.secondSplitter.sizes()
+        state_data.files_view_col_widths = [
+            self.filesView.header().sectionSize(idx)
+            for idx
+            in range(self.filesView.header().count())
+        ]
+        state_data.files_view_sorting = (
+            self.filesView.header().sortIndicatorSection(),
+            self.filesView.header().sortIndicatorOrder().value
+        )
 
         self.filesViewModel.deleteLater()
 
-        #umount
+        # umount
         try:
-            mnt = mount.Mount(cfg = self.config, parent = self)
+            mnt = mount.Mount(cfg=self.config, parent=self)
             mnt.umount(self.config.current_hash_id)
+
         except MountException as ex:
             messagebox.critical(self, str(ex))
 
         self.config.save()
+        state_data.save()
 
         # cleanup temporary local copies of files which were opened in GUI
         for d in self.tmpDirs:
@@ -899,7 +949,8 @@ class MainWindow(QMainWindow):
 
         self.comboProfiles.clear()
 
-        qttools.update_combo_profiles(self.config, self.comboProfiles, self.config.currentProfile())
+        qttools.update_combo_profiles(
+            self.config, self.comboProfiles, self.config.currentProfile())
         profiles = self.config.profilesSortedByName()
 
         self.comboProfilesAction.setVisible(len(profiles) > 1)
@@ -913,12 +964,18 @@ class MainWindow(QMainWindow):
         self.updatePlaces()
         self.updateFilesView(0)
 
+        profile_id = self.config.currentProfile()
+        state_data = StateData()
+        profile_state = state_data.profile(profile_id)
+
         # EncFS deprecation warning (see #1734)
-        current_mode = self.config.snapshotsMode(self.config.currentProfile())
+        current_mode = self.config.snapshotsMode(profile_id)
         if current_mode in ('local_encfs', 'ssh_encfs'):
-            # Show the profile specific warning dialog only once per profile.
-            if self.config.profileBoolValue('msg_shown_encfs') is False:
-                self.config.setProfileBoolValue('msg_shown_encfs', True)
+            # Show the profile specific warning dialog only once per profile
+            # and only if the global warning was shown before.
+            if (state_data.msg_encfs_global == bitbase.ENCFS_MSG_STAGE
+                    and profile_state.msg_encfs < bitbase.ENCFS_MSG_STAGE):
+                profile_state.msg_encfs = bitbase.ENCFS_MSG_STAGE
                 dlg = encfsmsgbox.EncfsCreateWarning(self)
                 dlg.exec()
 
@@ -969,10 +1026,14 @@ class MainWindow(QMainWindow):
 
     def remount(self, new_profile_id, old_profile_id):
         try:
-            mnt = mount.Mount(cfg = self.config, profile_id = old_profile_id, parent = self)
+            mnt = mount.Mount(cfg=self.config,
+                              profile_id=old_profile_id,
+                              parent=self)
             hash_id = mnt.remount(new_profile_id)
+
         except MountException as ex:
             messagebox.critical(self, str(ex))
+
         else:
             self.config.setCurrentHashId(hash_id)
 
@@ -981,7 +1042,7 @@ class MainWindow(QMainWindow):
         if raiseCmd is None:
             return
 
-        logger.debug("Raise cmd: %s" %raiseCmd, self)
+        logger.debug("Raise cmd: %s" % raiseCmd, self)
         self.qapp.alert(self)
 
     def updateTakeSnapshot(self, force_wait_lock=False):
@@ -1372,10 +1433,13 @@ class MainWindow(QMainWindow):
             dlg = AboutDlg(self)
             dlg.exec()
 
-    def btnHelpClicked(self):
+    def btn_help_user_manual(self):
+        qttools.open_user_manual()
+
+    def btn_help_man_backintime(self):
         self.openManPage('backintime')
 
-    def btnHelpConfigClicked(self):
+    def btn_help_man_config(self):
         self.openManPage('backintime-config')
 
     def btnWebsiteClicked(self):
@@ -1703,26 +1767,27 @@ class MainWindow(QMainWindow):
 
         self.openPath(rel_path)
 
-    def tmpCopy(self, full_path, sid = None):
-        """
-        Create a temporary local copy of the file ``full_path`` and add the
-        temp folder to ``self.tmpDirs`` which will remove them on exit.
+    def tmpCopy(self, full_path, sid=None):
+        """Create a temporary local copy a file or directory.
+
+        The name of is of the pattern ``backintime_[tmp_str]_[snapshotID]``.
+        Clean up is done when closing BIT based on ``self.tmpDirs``.
 
         Args:
-            full_path (str):        path to original file
-            sid (snapshots.SID):    snapshot ID used as temp folder suffix
+            full_path (str): Path to original file or directory.
+            sid (snapshots.SID): Snapshot identifier.
 
         Returns:
-            str:                    temporary path to file
+            str: Path to the temporary file or directory.
         """
         if sid:
             sid = '_' + sid.sid
 
-        d = TemporaryDirectory(suffix = sid)
+        d = TemporaryDirectory(prefix='backintime_', suffix=sid)
         tmp_file = os.path.join(d.name, os.path.basename(full_path))
 
         if os.path.isdir(full_path):
-            shutil.copytree(full_path, tmp_file)
+            shutil.copytree(full_path, tmp_file, symlinks=True)
         else:
             shutil.copy(full_path, d.name)
 
@@ -1755,13 +1820,24 @@ class MainWindow(QMainWindow):
                 self.run = QDesktopServices.openUrl(file_url)
 
     @pyqtSlot(int)
-    def updateFilesView(self, changed_from, selected_file = None, show_snapshots = False): #0 - files view change directory, 1 - files view, 2 - time_line, 3 - places
+    def updateFilesView(self,
+                        changed_from,
+                        selected_file=None,
+                        show_snapshots=False):
+        """
+        changed_from? WTF!
+            0 - files view change directory,
+            1 - files view,
+            2 - time_line,
+            3 - places
+        """
         if 0 == changed_from or 3 == changed_from:
             selected_file = ''
 
         if 0 == changed_from:
             # update places
             self.places.setCurrentItem(None)
+
             for place_index in range(self.places.topLevelItemCount()):
                 item = self.places.topLevelItem(place_index)
                 if self.path == str(item.data(0, Qt.ItemDataRole.UserRole)):
@@ -1771,6 +1847,7 @@ class MainWindow(QMainWindow):
         text = ''
         if self.sid.isRoot:
             text = _('Now')
+
         else:
             name = self.sid.displayName
             # buhtz (2023-07)3 blanks at the end of that string as a
@@ -1791,8 +1868,10 @@ class MainWindow(QMainWindow):
         full_path = self.sid.pathBackup(self.path)
 
         if os.path.isdir(full_path):
+
             if self.showHiddenFiles:
                 self.filesViewProxyModel.setFilterRegularExpression(r'')
+
             else:
                 self.filesViewProxyModel.setFilterRegularExpression(r'^[^\.]')
 
@@ -2015,11 +2094,17 @@ class MainWindow(QMainWindow):
     def _open_release_candidate_dialog(self):
         html_contact_list = (
             '<ul>'
+            '<li>{mastodon}</li>'
             '<li>{email}</li>'
             '<li>{mailinglist}</li>'
             '<li>{issue}</li>'
             '<li>{alternative}</li>'
             '</ul>').format(
+                mastodon=_('In the Fediverse at Mastodon: {link_and_label}') \
+                    .format(link_and_label='<a href="https://fosstodon.org'
+                                           '/@backintime">'
+                                           '@backintime@fosstodon.org'
+                                           '</a>'),
                 email=_('Email to {link_and_label}.').format(
                     link_and_label='<a href="mailto:backintime@tuta.io">'
                                    'backintime@tuta.io</a>'),
@@ -2129,6 +2214,7 @@ class ExtraMouseButtonEventFilter(QObject):
             return super(ExtraMouseButtonEventFilter, self) \
                 .eventFilter(receiver, event)
 
+
 class RemoveSnapshotThread(QThread):
     """
     remove snapshots in background thread so GUI will not freeze
@@ -2197,6 +2283,173 @@ class SetupCron(QThread):
         self.config.setupCron()
 
 
+def _get_state_data_from_config(cfg: config.Config) -> StateData:
+    """Get data related to application state from the config instance.
+
+    It migrates state data from the config file to an instance of
+    `StateData` which later is saved in a separate file.
+
+    This function is a temporary workaround. See PR #1850.
+
+    Args:
+       cfg: The config instance.
+
+    Returns:
+        dict: The state data.
+        """
+
+    data = StateData()
+
+    # internal.manual_starts_countdown
+    data['manual_starts_countdown'] \
+        = cfg.intValue('internal.manual_starts_countdown', 10)
+
+    # internal.msg_rc
+    val = cfg.strValue('internal.msg_rc', None)
+    if val:
+        data.msg_release_candidate = val
+
+    # internal.msg_shown_encfs
+    val = cfg.boolValue('internal.msg_shown_encfs', 0)
+    if val:
+        data.msg_encfs_global = val
+
+    # qt.show_hidden_files
+    data.mainwindow_show_hidden = cfg.boolValue('qt.show_hidden_files', False)
+
+    # Coordinates and dimensions
+    val = (
+        cfg.intValue('qt.main_window.x', None),
+        cfg.intValue('qt.main_window.y', None)
+    )
+
+    if all(val):
+        data.mainwindow_coords = val
+
+    val = (
+        cfg.intValue('qt.main_window.width', None),
+        cfg.intValue('qt.main_window.height', None)
+    )
+    if all(val):
+        data.mainwindow_dims = val
+
+    val = (
+        cfg.intValue('qt.logview.width', None),
+        cfg.intValue('qt.logview.height', None)
+    )
+    if all(val):
+        data.logview_dims = val
+
+    # files view
+    # Dev note (buhtz, 2024-12): Ignore the column width values because of a
+    # bug. Three columns are tracked but the widget has four columns. The "Typ"
+    # column is treated as "Date" and the width of the real "Date" column (4th)
+    # was never stored.
+    # The new state file will load and store width values for all existing
+    # columns.
+    # qt.main_window.files_view.name_width
+    # qt.main_window.files_view.size_width
+    # qt.main_window.files_view.date_width
+
+    col = cfg.intValue('qt.main_window.files_view.sort.column', 0)
+    order = cfg.boolValue('qt.main_window.files_view.sort.ascending', True)
+    data.files_view_sorting = (col, 0 if order else 1)
+
+    # splitter width
+    widths = (
+        cfg.intValue('qt.main_window.main_splitter_left_w', None),
+        cfg.intValue('qt.main_window.main_splitter_right_w', None)
+    )
+    if all(widths):
+        data.mainwindow_main_splitter_widths = widths
+
+    widths = (
+        cfg.intValue('qt.main_window.second_splitter_left_w', None),
+        cfg.intValue('qt.main_window.second_splitter_right_w', None)
+    )
+    if all(widths):
+        data.mainwindow_second_splitter_widths = widths
+
+    # each profile
+    for profile_id in cfg.profiles():
+        profile_state = data.profile(profile_id)
+
+        # profile specific encfs warning
+        val = cfg.profileBoolValue('msg_shown_encfs', 0, profile_id)
+        profile_state.msg_encfs = val
+
+        # qt.last_path
+        if cfg.hasProfileKey('qt.last_path', profile_id):
+            profile_state.last_path \
+                = cfg.profileStrValue('qt.last_path', None, profile_id)
+
+        # Places: sorting
+        sorting = (
+            cfg.profileIntValue('qt.places.SortColumn', None, profile_id),
+            cfg.profileIntValue('qt.places.SortOrder', None, profile_id)
+        )
+        if all(sorting):
+            profile_state.places_sorting = sorting
+
+        # Manage profiles - Exclude tab: sorting
+        sorting = (
+            cfg.profileIntValue(
+                'qt.settingsdialog.exclude.SortColumn', None, profile_id),
+            cfg.profileIntValue(
+                'qt.settingsdialog.exclude.SortOrder', None, profile_id)
+        )
+        if all(sorting):
+            profile_state.exclude_sorting = sorting
+
+        # Manage profiles - Include tab: sorting
+        sorting = (
+            cfg.profileIntValue(
+                'qt.settingsdialog.include.SortColumn', None, profile_id),
+            cfg.profileIntValue(
+                'qt.settingsdialog.include.SortOrder', None, profile_id)
+        )
+        if all(sorting):
+            profile_state.include_sorting = sorting
+
+    return data
+
+
+def load_state_data(cfg: config.Config) -> None:
+    """Initiate the `State` instance.
+
+    The state file is loaded and its data stored in `State`. The later is a
+    singleton and can be used everywhere.
+
+    Args:
+       args: Arguments given from command line.
+    """
+    fp = StateData.file_path()
+
+    try:
+        # load file
+        state_data = StateData(json.loads(fp.read_text(encoding='utf-8')))
+
+    except FileNotFoundError:
+        logger.debug('State file not found. Using config file and migrate it'
+                     'into a state file.')
+        fp.parent.mkdir(parents=True, exist_ok=True)
+        state_data = _get_state_data_from_config(cfg)
+
+    except json.decoder.JSONDecodeError as exc:
+        logger.warning(f'Unable to read and decode state file "{fp}". '
+                       'Ignnoring it.')
+        logger.debug(f'{exc=}')
+
+        try:
+            raw_content = fp.read_text(encoding='utf-8')
+            logger.debug(f'raw_content="{raw_content}"')
+        except Exception as exc_raw:
+            logger.debug(f'{exc_raw=}')
+
+        # Empty state data with default values
+        state_data = StateData()
+
+
 if __name__ == '__main__':
     cfg = backintime.startApp('backintime-qt')
 
@@ -2214,6 +2467,8 @@ if __name__ == '__main__':
     translator = qttools.initiate_translator(cfg.language())
     qapp.installTranslator(translator)
 
+    load_state_data(cfg)
+
     mainWindow = MainWindow(cfg, appInstance, qapp)
 
     if cfg.isConfigured():
